/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - MBeanActionInfo.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/

package org.snmp4j.agent.mo.jmx;

/**
 * The <code>MBeanActionInfo</code> defines a MBean action. The information
 * needed to call a MBean action includes method name, parameters, and
 * optionally the concrete signature of the method implementing the action.
 * The action ID identifies the action
 *
 * @author Frank Fock
 * @version 1.0
 */
public class MBeanActionInfo {

  private int actionID;
  private String method;
  private Object[] parameters = new Object[0];
  private String[] signature = new String[0];

  public MBeanActionInfo(int actionID, String actionMethod) {
    this.actionID = actionID;
    this.method = actionMethod;
  }

  public MBeanActionInfo(int actionID, String actionMethod,
                         Object[] actionParameters) {
    this(actionID, actionMethod);
    if (actionParameters != null) {
      this.parameters = actionParameters;
      String[] signature = new String[actionParameters.length];
      for (int i = 0; i < actionParameters.length; i++) {
        signature[i] = actionParameters[i].getClass().getName();
      }
    }
  }

  public MBeanActionInfo(int actionID, String actionMethod,
                         Object[] actionParameters,
                         String[] signature) {
    this(actionID, actionMethod);
    this.parameters = actionParameters;
    this.signature = signature;
  }

  public int getActionID() {
    return actionID;
  }

  public String getMethod() {
    return method;
  }

  public Object[] getParameters() {
    return parameters;
  }

  public String[] getSignature() {
    return signature;
  }

}
